@@ -8,6 +8,7 @@ They give only static definitions of paths.
 """
 from collections.abc import Mapping
 from difflib import get_close_matches
+from functools import lru_cache
 from typing import (
     Any,
     Callable,
@@ -21,6 +22,7 @@ from typing import (
     Sequence,
     Tuple,
     Type,
+    TypeVar,
     Union,
 )
 from urllib.parse import quote, unquote, urljoin, urlsplit, urlunsplit
@@ -36,8 +38,19 @@ from .exceptions import InvalidSchema, UsageError
 from .hooks import HookContext, HookDispatcher, HookScope, dispatch
 from .models import APIOperation, Case
 from .stateful import APIStateMachine, Stateful, StatefulTest
-from .types import Filter, FormData, GenericTest, NotSet
-from .utils import NOT_SET, PARAMETRIZE_MARKER, Err, GenericResponse, GivenInput, Ok, Result, given_proxy
+from .types import (
+    Body,
+    Cookies,
+    DataGenerationMethodInput,
+    Filter,
+    FormData,
+    GenericTest,
+    Headers,
+    NotSet,
+    PathParameters,
+    Query,
+)
+from .utils import NOT_SET, PARAMETRIZE_MARKER, GenericResponse, GivenInput, Ok, Result, given_proxy
 
 
 class MethodsDict(CaseInsensitiveDict):
@@ -55,6 +68,14 @@ class MethodsDict(CaseInsensitiveDict):
             raise KeyError(message) from exc
 
 
+C = TypeVar("C", bound=Case)
+
+
+@lru_cache()
+def get_full_path(base_path: str, path: str) -> str:
+    return unquote(urljoin(base_path, quote(path.lstrip("/"))))  # pragma: no mutate
+
+
 @attr.s(eq=False)  # pragma: no mutate
 class BaseSchema(Mapping):
     raw_schema: Dict[str, Any] = attr.ib()  # pragma: no mutate
@@ -96,7 +117,7 @@ class BaseSchema(Mapping):
 
     def get_full_path(self, path: str) -> str:
         """Compute full path for the given path."""
-        return unquote(urljoin(self.base_path, quote(path.lstrip("/"))))  # pragma: no mutate
+        return get_full_path(self.base_path, path)
 
     @property
     def base_path(self) -> str:
@@ -135,14 +156,7 @@ class BaseSchema(Mapping):
 
     @property
     def operations_count(self) -> int:
-        total = 0
-        # Avoid creating a list of all operation - for large schemas it consumes too much memory
-        for result in self.get_all_operations():
-            if isinstance(result, Ok) or (isinstance(result, Err) and result.err().method is not None):
-                total += 1
-            # In the `Err` case without `method` we don't know how many operations are there.
-            # it happens when all operations are behind an unresolvable reference
-        return total
+        raise NotImplementedError
 
     def get_all_operations(self) -> Generator[Result[APIOperation, InvalidSchema], None, None]:
         raise NotImplementedError
@@ -245,7 +259,7 @@ class BaseSchema(Mapping):
         hooks: Union[HookDispatcher, NotSet] = NOT_SET,
         validate_schema: Union[bool, NotSet] = NOT_SET,
         skip_deprecated_operations: Union[bool, NotSet] = NOT_SET,
-        data_generation_methods: Union[Iterable[DataGenerationMethod], NotSet] = NOT_SET,
+        data_generation_methods: Union[DataGenerationMethodInput, NotSet] = NOT_SET,
         code_sample_style: Union[CodeSampleStyle, NotSet] = NOT_SET,
     ) -> "BaseSchema":
         if base_url is NOT_SET:
@@ -316,6 +330,20 @@ class BaseSchema(Mapping):
     def get_request_payload_content_types(self, operation: APIOperation) -> List[str]:
         raise NotImplementedError
 
+    def make_case(
+        self,
+        *,
+        case_cls: Type[C],
+        operation: APIOperation,
+        path_parameters: Optional[PathParameters] = None,
+        headers: Optional[Headers] = None,
+        cookies: Optional[Cookies] = None,
+        query: Optional[Query] = None,
+        body: Union[Body, NotSet] = NOT_SET,
+        media_type: Optional[str] = None,
+    ) -> C:
+        raise NotImplementedError
+
     def get_case_strategy(
         self,
         operation: APIOperation,
